.. _design_principles:

Design Principles
=================

When developing Pootle we strive to achieve these principles:

.. These are the Virtaal design principles for guidance while we nail some
   Pootle principles:
     1. Good looking
     2. Optimise for the most frequent use cases
     3. No necessity for mouse
     4. The most important information must be visible by default
     5. Only relevant (actionable) widgets should be shown
     6. Maximum functionality without setup

1. Snappy
2. Good set of default settings
3. The most important information must be visible by default
4. Only relevant (actionable) information should be shown

Where these mean...

Snappy
------

The user experience of interacting with Pootle is quick or Snappy.  Essentially
the user should not feel that they are waiting for Pootle.

Good set of default settings
----------------------------

A default Pootle install from source should be well configured with a standard
set of feature.  Essoteric features should be documented but not enabled by
default.

The most important information must be visible by default
---------------------------------------------------------

The user should not have to click anywhere to find important relevant
information it should just be available.

Only relevant (actionable) information should be shown
------------------------------------------------------

We show information that the user can act on.  Thus we show terms that are used
in the source, Translation Memory that matches the source.
